**KerdokuBot Stats Package.**

**Installation** \
To install KerdokuStats:\
```$ pip install kerdokustats```


**Example code:**

```py
import kerdokustats

guilds = kerdoku().guilds #Show bot guilds count
users = kerdoku().users #Show bot users count
time = kerdoku().time #Show bot LSRT

print(guilds)
print(users)
print(time)
```

If you have a question or idea, go to KerdokuBot technical support server. https://kerdokuds.ml

